// src/index.ts
import {getHighlighter} from "@antfu/shiki";
import deasync from "deasync";
import Debug from "debug";
var debug = Debug("markdown-it-shiki");
var MarkdownItShiki = (markdownit, options = {}) => {
  let _highlighter = void 0;
  const themes = [];
  let darkModeThemes;
  if (!options.theme) {
    themes.push("nord");
  } else if (typeof options.theme === "string") {
    themes.push(options.theme);
  } else {
    darkModeThemes = options.theme;
    themes.push(options.theme.dark);
    themes.push(options.theme.light);
  }
  getHighlighter({themes}).then((h) => {
    _highlighter = h;
  });
  markdownit.options.highlight = (code, lang) => {
    if (!_highlighter) {
      debug("awaiting getHighlighter()");
      let count = 0;
      while (!_highlighter) {
        deasync.sleep(100);
        count += 1;
        if (count > 50) {
          throw new Error("Shiki.getHighlighter() never gest resolved");
        }
      }
      debug("getHighlighter() resolved");
    }
    if (darkModeThemes) {
      const dark = _highlighter.codeToHtml(code, lang || "text", darkModeThemes.dark);
      const light = _highlighter.codeToHtml(code, lang || "text", darkModeThemes.light);
      return dark.replace('<pre class="shiki"', '<pre class="shiki shiki-dark"') + light.replace('<pre class="shiki"', '<pre class="shiki shiki-light"');
    } else {
      return _highlighter.codeToHtml(code, lang || "text");
    }
  };
};
var src_default = MarkdownItShiki;
export {
  src_default as default
};
